---
title: NHN KCP 가상계좌 환급시 입금자명 변경방법
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 결제취소/환불
seo:
  title: KCP 가상계좌 환급시 통장내역의 입금자명 변경방법
  description: >-
    KCP 입금자명 변경 방법에 대한 안내입니다. 가상계좌 거래 환불은 환불요청 이후 익영업일 내 고객의 계좌에 환급이 이루어집니다. 환급
    시 고객 통장 거래내역에 표기되는 입금자 명을 변경하고자 하실 경우, 포트원 가이드를 참고 바랍니다.
  keywords:
    - 가상계좌
tags:
  - NHN KCP
  - 가상계좌
  - 결제취소-환불
pgCompanies:
  - NHN KCP
searchTags:
  - KCP입금자명
  - 통장인자명
  - 입금자명
  - 입금자명 변경
  - kcp가상계좌
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="NHN KCP 입금자명 변경 방법을 안내해드립니다." />

<Callout content="1. 가상계좌 거래 환불은 환불요청 이후 익영업일 내 고객의 계좌에 환급이 이루어집니다.
2. 환급 시 고객의 통장 거래내역에 표기되는 ‘입금자(=통장인 자명)’명을 변경하고자 하실 경우 
아래 변경요청방법을 참고해 주시기 바랍니다. 
(기존에는 ‘한국사이버결제’로 표기되어 환급됨)
" icon="💡" title="참고사항" />

### **통장인자명 변경 요청방법**

- [NHN KCP 어드민페이지↗](https://partner.kcp.co.kr/auth/login) 로그인 > 고객센터 > 질문하기 > 기타문의
- 문의내용
  - (예시) 가상계좌 환급시 통장거래내역의 입금자명(통장인자명) 변경을 요청드립니다. \
    \- KCP 사이트코드 (상점아이디) :\
    \- 변경요청하는 통장인자명 :



<Callout content="1. 국문/영문 모두 가능 합니다. (8자까지 가능)
2. 통장인자명이란, 가상계좌 건 환불 시 고객(주문자)의 통장에 표기되는 문구입니다.
" icon="💡" title="참고사항" />
